DSFirebaseAuthProvider class

Firebase authentication provider

Constructors

DSFirebaseAuthProvider({required String projectId, required String privateKeyPath, required String apiKey})
factory

Properties

apiKey String
final
hashCode int
The hash code for this object.
no setterinherited
privateKeyPath String
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAccount(String email, String password, {String? displayName}) Future<void>
Creates a new user account with the given credentials
override
deleteUser() Future<void>
getCurrentUser() Future<DSAuthUser>
Retrieves the currently authenticated user
override
getUser(String userId) Future<DSAuthUser>
Retrieves a user by their ID
override
initialize(Map<String, dynamic> config) Future<void>
Initializes the provider with configuration settings
override
isEmailVerified() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLoginSuccess(DSAuthUser user) Future<void>
Lifecycle hooks
override
onLogout() Future<void>
Lifecycle hooks
override
refreshToken(String refreshToken) Future<String>
Refreshes the current user's token
override
sendEmailVerification() Future<void>
signIn(String username, String password) Future<void>
Signs in a user with the given credentials
override
signOut() Future<void>
Signs out the current user
override
toString() String
A string representation of this object.
inherited
updateEmail(String newEmail) Future<void>
updatePassword(String newPassword) Future<void>
verifyToken([String? token]) Future<bool>
Retrieves the current user's token
override

Operators

operator ==(Object other) bool
The equality operator.
inherited